==> surveyplat-proof-common-zjgg-1.0.0-20191013.075046-12-sources.jar: cn/gtmap/surveyplat/common/entity/DcjzJzfj.java <==
package cn.gtmap.surveyplat.common.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created by Administrator on 2018/5/2.
 * 举证附件
 */
@Table(name = "dcjz_jzfj")
public class DcjzJzfj {

    @Id
    //主键
    private String jzfjid;

    //图斑id
    private String tbid;

    //附件类型 (1：图片 2：视频)
    private String fjlx;

    //经度
    private Double jd;

    //纬度
    private Double wd;

    //附件名称
    private String fjmc;

    //附件路径
    private String fjlj;

    //拍摄时间
    private Date pssj;

    //拍摄角度
    private Double psjd;

    //拍摄人员
    private String psry;

    //任务id
    private String jzrwid;

    //备注
    private String bz;

    /**
     *校验码
     */
    private String jym;

    public String getJym() {
        return jym;
    }

    public void setJym(String jym) {
        this.jym = jym;
    }

    public String getJzfjid() {
        return jzfjid;
    }

    public void setJzfjid(String jzfjid) {
        this.jzfjid = jzfjid;
    }

    public String getTbid() {
        return tbid;
    }

    public void setTbid(String tbid) {
        this.tbid = tbid;
    }

    public String getFjlx() {
        return fjlx;
    }

    public void setFjlx(String fjlx) {
        this.fjlx = fjlx;
    }


    public String getFjmc() {
        return fjmc;
    }

    public void setFjmc(String fjmc) {
        this.fjmc = fjmc;
    }

    public String getFjlj() {
        return fjlj;
    }

    public void setFjlj(String fjlj) {
        this.fjlj = fjlj;
    }

    public Date getPssj() {
        return pssj;
    }

    public void setPssj(Date pssj) {
        this.pssj = pssj;
    }

    public Double getJd() {
        return jd;
    }

    public void setJd(Double jd) {
        this.jd = jd;
    }

    public Double getWd() {
        return wd;
    }

    public void setWd(Double wd) {
        this.wd = wd;
    }

    public Double getPsjd() {
        return psjd;
    }

    public void setPsjd(Double psjd) {
        this.psjd = psjd;
    }

    public String getPsry() {
        return psry;
    }

    public void setPsry(String psry) {
        this.psry = psry;
    }

    public String getJzrwid() {
        return jzrwid;
    }

    public void setJzrwid(String jzrwid) {
        this.jzrwid = jzrwid;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> surveyplat-proof-common-zjgg-1.0.0-20191018.010839-16-sources.jar: cn/gtmap/surveyplat/common/entity/DcjzJzfj.java <==
package cn.gtmap.surveyplat.common.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * Created by Administrator on 2018/5/2.
 * 举证附件
 */
@Table(name = "dcjz_jzfj")
public class DcjzJzfj {

    @Id
    //主键
    private String jzfjid;

    //图斑id
    private String tbid;

    //附件类型 (1：图片 2：视频)
    private String fjlx;

    //经度
    private Double jd;

    //纬度
    private Double wd;

    //附件名称
    private String fjmc;

    //附件路径
    private String fjlj;

    //拍摄时间
    private Date pssj;

    //拍摄角度
    private Double psjd;

    //拍摄人员
    private String psry;

    //任务id
    private String jzrwid;

    //备注
    private String bz;

    /**
     *校验码
     */
    private String jym;

    //视频学习
    private String spxx;

    public String getSpxx() {
        return spxx;
    }

    public void setSpxx(String spxx) {
        this.spxx = spxx;
    }

    public String getJym() {
        return jym;
    }

    public void setJym(String jym) {
        this.jym = jym;
    }

    public String getJzfjid() {
        return jzfjid;
    }

    public void setJzfjid(String jzfjid) {
        this.jzfjid = jzfjid;
    }

    public String getTbid() {
        return tbid;
    }

    public void setTbid(String tbid) {
        this.tbid = tbid;
    }

    public String getFjlx() {
        return fjlx;
    }

    public void setFjlx(String fjlx) {
        this.fjlx = fjlx;
    }


    public String getFjmc() {
        return fjmc;
    }

    public void setFjmc(String fjmc) {
        this.fjmc = fjmc;
    }

    public String getFjlj() {
        return fjlj;
    }

    public void setFjlj(String fjlj) {
        this.fjlj = fjlj;
    }

    public Date getPssj() {
        return pssj;
    }

    public void setPssj(Date pssj) {
        this.pssj = pssj;
    }

    public Double getJd() {
        return jd;
    }

    public void setJd(Double jd) {
        this.jd = jd;
    }

    public Double getWd() {
        return wd;
    }

    public void setWd(Double wd) {
        this.wd = wd;
    }

    public Double getPsjd() {
        return psjd;
    }

    public void setPsjd(Double psjd) {
        this.psjd = psjd;
    }

    public String getPsry() {
        return psry;
    }

    public void setPsry(String psry) {
        this.psry = psry;
    }

    public String getJzrwid() {
        return jzrwid;
    }

    public void setJzrwid(String jzrwid) {
        this.jzrwid = jzrwid;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}
